AutoArchive._ui._cmdline — AutoArchive Developer Manual (ver. 1.0.4)

# AutoArchive._ui._cmdline

Cmdline UI component.

Package defines a Mainf component for a command-line user interface.

## Sub-Packages

- AutoArchive._ui._cmdline._core

## Modules

### cmdline_commands

`CmdlineCommands` and `CmdlineCommandsUtils` static classes.

class `AutoArchive._ui._cmdline.cmdline_commands.` `CmdlineCommands`

  Bases: `object`

  Constants for command-line command names.

  Command-line commands are used to invoke program operations via a command-line argument. For example: `--create` will invoke a backup creation.

  Note

  It is not allowed to change values of these constants.

  `CREATE` = 'create'

    Create backup for a given archive specification file.

  `LIST` = 'list'

    List all archive specification files.

  `PURGE` = 'purge'

    Purge orphaned archive data.

class `AutoArchive._ui._cmdline.cmdline_commands.` `CmdlineCommandsUtils`

  Bases: `object`

  Various utility methods working with `CmdlineCommands`.

  static `getAllCommands`()

    Iterator over all known commands.

    Returns: | All options defined in `CmdlineCommands`.
    Return type: | `Iterable<str>`

  classmethod `isExistingCommand`(commandName)

    Check whether a command with name `commandName` does exists in `CmdlineCommandsUtils`.

    Parameters: | commandName (`str`) – Name of the command which existence shall be checked.
    Returns: | `True` if option with name `commandName` exists; `False` otherwise.
    Return type: | `bool`